@@ -104,6 +104,7 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
 
   expect_equal(recommended_dose(x), 5)
   expect_true(is.integer(recommended_dose(x)))
+  expect_equal(length(recommended_dose(x)), 1)
 
   expect_equal(continue(x), TRUE)
   expect_true(is.logical(continue(x)))
@@ -112,6 +113,22 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
   expect_true(is.integer(n_at_dose(x)))
   expect_equal(length(n_at_dose(x)), num_doses(x))
 
+  expect_equal(n_at_dose(x, dose = 0), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 0)))
+  expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+  expect_equal(n_at_dose(x, dose = 1), 3)
+  expect_true(is.integer(n_at_dose(x, dose = 1)))
+  expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+  expect_equal(n_at_dose(x, dose = 'recommended'), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+  expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+  expect_equal(n_at_recommended_dose(x), 0)
+  expect_true(is.integer(n_at_recommended_dose(x)))
+  expect_equal(length(n_at_recommended_dose(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -179,6 +196,7 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
 
   expect_equal(recommended_dose(x), 1)
   expect_true(is.integer(recommended_dose(x)))
+  expect_equal(length(recommended_dose(x)), 1)
 
   expect_equal(continue(x), TRUE)
   expect_true(is.logical(continue(x)))
@@ -187,6 +205,22 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
   expect_true(is.integer(n_at_dose(x)))
   expect_equal(length(n_at_dose(x)), num_doses(x))
 
+  expect_equal(n_at_dose(x, dose = 0), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 0)))
+  expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+  expect_equal(n_at_dose(x, dose = 1), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 1)))
+  expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+  expect_equal(n_at_dose(x, dose = 'recommended'), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+  expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+  expect_equal(n_at_recommended_dose(x), 0)
+  expect_true(is.integer(n_at_recommended_dose(x)))
+  expect_equal(length(n_at_recommended_dose(x)), 1)
+
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -260,6 +294,7 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
 
   expect_equal(recommended_dose(x), 2)
   expect_true(is.integer(recommended_dose(x)))
+  expect_equal(length(recommended_dose(x)), 1)
 
   expect_equal(continue(x), TRUE)
   expect_true(is.logical(continue(x)))
@@ -268,6 +303,22 @@ test_that('stop_when_tox_ci_covered_selector supports correct interface.', {
   expect_true(is.integer(n_at_dose(x)))
   expect_equal(length(n_at_dose(x)), num_doses(x))
 
+  expect_equal(n_at_dose(x, dose = 0), 0)
+  expect_true(is.integer(n_at_dose(x, dose = 0)))
+  expect_equal(length(n_at_dose(x, dose = 0)), 1)
+
+  expect_equal(n_at_dose(x, dose = 1), 3)
+  expect_true(is.integer(n_at_dose(x, dose = 1)))
+  expect_equal(length(n_at_dose(x, dose = 1)), 1)
+
+  expect_equal(n_at_dose(x, dose = 'recommended'), 3)
+  expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
+  expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
+
+  expect_equal(n_at_recommended_dose(x), 3)
+  expect_true(is.integer(n_at_recommended_dose(x)))
+  expect_equal(length(n_at_recommended_dose(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
